@@ -9,7 +9,7 @@ PUBLIC CLASSES AND METHODS:
    cComm
       This class wraps low level port communications
 
-Copyright (c) 2011, Code Aurora Forum. All rights reserved.
+Copyright (c) 2013, The Linux Foundation. All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:
@@ -18,10 +18,9 @@ modification, are permitted provided that the following conditions are met:
     * Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in the
       documentation and/or other materials provided with the distribution.
-    * Neither the name of Code Aurora Forum nor
-      the names of its contributors may be used to endorse or promote
-      products derived from this software without specific prior written
-      permission.
+    * Neither the name of The Linux Foundation nor the names of its
+      contributors may be used to endorse or promote products derived from 
+      this software without specific prior written permission.
 
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
@@ -120,6 +119,7 @@ void * RxThread( void * pData )
          else
          {
             // EXIT_CMD or anything else
+            pComm->mpRxCallback = 0;
             break;
          }
       }
@@ -172,7 +172,6 @@ RETURN VALUE:
 cComm::cComm()
    :  mPortName( "" ),
       mPort( INVALID_HANDLE_VALUE ),
-      mpRxCallback( 0 ),
       mbCancelWrite( false ),
       mpBuffer( 0 ),
       mBuffSz( 0 ),
@@ -280,7 +279,7 @@ bool cComm::Connect( LPCSTR pPort )
 
 /*===========================================================================
 METHOD:
-   RunIOCTL (Public Method)
+   SendCtl (Public Method)
 
 DESCRIPTION:
    Run an IOCTL on the open file handle
@@ -292,7 +291,7 @@ PARAMETERS:
 RETURN VALUE:
    int - ioctl return value (0 for success)
 ===========================================================================*/
-int cComm::RunIOCTL(
+int cComm::SendCtl(
    UINT     ioctlReq,
    void *   pData )
 {
@@ -329,7 +328,7 @@ bool cComm::Disconnect()
          write( mCommandPipe[WRITING], &byte, 1 );
 
          // And wait for it
-         TRACE( "cComm::Disconnnect() joining thread\n" );
+         TRACE( "cComm::Disconnnect() joining thread %lu\n", mRxThreadID );
          int nRC = pthread_join( mRxThreadID, 0 );
          if (nRC != 0)
          {
@@ -352,6 +351,9 @@ bool cComm::Disconnect()
       mPort = INVALID_HANDLE_VALUE;
    }
 
+   // Double check
+   mpRxCallback = 0;
+
    mPortName.clear();
    return bRC;
 }
@@ -461,6 +463,7 @@ bool cComm::CancelRx()
    ||  mRxThreadID == 0)
    {
       TRACE( "cannot cancel, thread not active\n" );
+      mpRxCallback = 0;
       return false;
    }
 
@@ -592,7 +595,7 @@ bool cComm::TxData(
    fd_set set;
    
    int nReady = 0;
-   int nCount = 0;
+   unsigned int nCount = 0;
    
    while ( nReady == 0 )
    {
@@ -626,8 +629,8 @@ bool cComm::TxData(
       return false;
    }
    
-   int nRet = write( mPort, pBuf, bufSz );
-   if (nRet != bufSz)
+   size_t nRet = write( mPort, pBuf, bufSz );
+   if (nRet == std::string::npos || nRet != bufSz)
    {
       TRACE( "cComm::TxData() write returned %d instead of %lu\n",
              nRet,
@@ -636,7 +639,7 @@ bool cComm::TxData(
    }
 
 #ifdef DEBUG
-   TRACE( "Write of %lu bytes took %llu miliseconds\n", bufSz, GetTickCount() - nStart );
+   TRACE( "Write of %lu bytes took %llu milliseconds\n", bufSz, GetTickCount() - nStart );
 #endif
 
    return true;
