@@ -53,6 +53,7 @@
  * @QMI_NAS_RADIO_INTERFACE_LTE: LTE.
  * @QMI_NAS_RADIO_INTERFACE_TD_SCDMA: TD-SCDMA.
  * @QMI_NAS_RADIO_INTERFACE_5GNR: 5G NR. Since 1.26.
+ * @QMI_NAS_RADIO_INTERFACE_NO_CHANGE: Keep the current radio interface. Since 1.38.
  *
  * Radio interface technology.
  *
@@ -69,6 +70,7 @@ typedef enum { /*< since=1.0 >*/
     QMI_NAS_RADIO_INTERFACE_LTE         = 0x08,
     QMI_NAS_RADIO_INTERFACE_TD_SCDMA    = 0x09,
     QMI_NAS_RADIO_INTERFACE_5GNR        = 0x0C,
+    QMI_NAS_RADIO_INTERFACE_NO_CHANGE   = 0xFF,
 } QmiNasRadioInterface;
 
 /**
@@ -463,6 +465,7 @@ typedef enum { /*< since=1.0 >*/
  * @QMI_NAS_NETWORK_SCAN_TYPE_UMTS: UMTS network.
  * @QMI_NAS_NETWORK_SCAN_TYPE_LTE: LTE network.
  * @QMI_NAS_NETWORK_SCAN_TYPE_TD_SCDMA: TD-SCDMA network.
+ * @QMI_NAS_NETWORK_SCAN_TYPE_5GNR: 5G NR network. Since 1.38.
  *
  * Flags to use when specifying which networks to scan.
  *
@@ -472,7 +475,8 @@ typedef enum { /*< since=1.0 >*/
     QMI_NAS_NETWORK_SCAN_TYPE_GSM      = 1 << 0,
     QMI_NAS_NETWORK_SCAN_TYPE_UMTS     = 1 << 1,
     QMI_NAS_NETWORK_SCAN_TYPE_LTE      = 1 << 2,
-    QMI_NAS_NETWORK_SCAN_TYPE_TD_SCDMA = 1 << 3
+    QMI_NAS_NETWORK_SCAN_TYPE_TD_SCDMA = 1 << 3,
+    QMI_NAS_NETWORK_SCAN_TYPE_5GNR     = 1 << 4,
 } QmiNasNetworkScanType;
 
 /**
@@ -491,6 +495,22 @@ typedef enum { /*< since=1.24 >*/
     QMI_NAS_NETWORK_SCAN_RESULT_RADIO_LINK_FAILURE = 2,
 } QmiNasNetworkScanResult;
 
+/**
+ * QmiNasIncrementalNetworkScanStatus:
+ * @QMI_NAS_INCREMENTAL_NETWORK_SCAN_STATUS_COMPLETE: Scan complete.
+ * @QMI_NAS_INCREMENTAL_NETWORK_SCAN_STATUS_PARTIAL: Partial results.
+ * @QMI_NAS_INCREMENTAL_NETWORK_SCAN_STATUS_ABORTED: Scan aborted.
+ *
+ * Incremental network scan status.
+ *
+ * Since: 1.38
+ */
+typedef enum { /*< since=1.38 >*/
+    QMI_NAS_INCREMENTAL_NETWORK_SCAN_STATUS_COMPLETE          = 0,
+    QMI_NAS_INCREMENTAL_NETWORK_SCAN_STATUS_PARTIAL           = 1,
+    QMI_NAS_INCREMENTAL_NETWORK_SCAN_STATUS_ABORTED           = 2,
+} QmiNasIncrementalNetworkScanStatus;
+
 /**
  * QmiNasNetworkStatus:
  * @QMI_NAS_NETWORK_STATUS_CURRENT_SERVING: Network is in use, current serving.
