@@ -31,6 +31,7 @@
 /**
  * SECTION: qmi-enums-pds
  * @title: PDS enumerations and flags
+ * @short_description: Enumerations and flags in the PDS service.
  *
  * This section defines enumerations and flags used in the PDS service
  * interface.
@@ -50,19 +51,13 @@
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_PDS_OPERATION_MODE_UNKNOWN     = -1,
     QMI_PDS_OPERATION_MODE_STANDALONE  =  0,
     QMI_PDS_OPERATION_MODE_MS_BASED    =  1,
     QMI_PDS_OPERATION_MODE_MS_ASSISTED =  2
 } QmiPdsOperationMode;
 
-/**
- * qmi_pds_operation_mode_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiPdsPositionSessionStatus:
  * @QMI_PDS_POSITION_SESSION_STATUS_SUCCESS: Success.
@@ -79,7 +74,7 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_PDS_POSITION_SESSION_STATUS_SUCCESS                  = 0x00,
     QMI_PDS_POSITION_SESSION_STATUS_IN_PROGRESS              = 0x01,
     QMI_PDS_POSITION_SESSION_STATUS_GENERAL_FAILURE          = 0x02,
@@ -91,12 +86,6 @@ typedef enum {
     QMI_PDS_POSITION_SESSION_STATUS_E911_SESSION_IN_PROGRESS = 0x08
 } QmiPdsPositionSessionStatus;
 
-/**
- * qmi_pds_position_session_status_get_string:
- *
- * Since: 1.0
- */
-
 /**
  * QmiPdsDataValid:
  * @QMI_PDS_DATA_VALID_TIMESTAMP_CALENDAR: Timestamp calendar (GPS time).
@@ -127,7 +116,7 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_PDS_DATA_VALID_TIMESTAMP_CALENDAR      = 1 << 0,
     QMI_PDS_DATA_VALID_TIMESTAMP_UTC           = 1 << 1,
     QMI_PDS_DATA_VALID_LEAP_SECONDS            = 1 << 2,
@@ -153,12 +142,6 @@ typedef enum {
     QMI_PDS_DATA_VALID_OPERATING_MODE          = 1 << 22
 } QmiPdsDataValid;
 
-/**
- * qmi_pds_data_valid_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI PDS Get GPS Service State' request/response */
 
@@ -172,18 +155,12 @@ typedef enum {
  *
  * Since: 1.0
  */
-typedef enum {
+typedef enum { /*< since=1.0 >*/
     QMI_PDS_TRACKING_SESSION_STATE_UNKNOWN  = 0,
     QMI_PDS_TRACKING_SESSION_STATE_INACTIVE = 1,
     QMI_PDS_TRACKING_SESSION_STATE_ACTIVE   = 2
 } QmiPdsTrackingSessionState;
 
-/**
- * qmi_pds_tracking_session_state_get_string:
- *
- * Since: 1.0
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI PDS Get Default Tracking Session' request/response */
 
@@ -197,18 +174,12 @@ typedef enum {
  *
  * Since: 1.12
  */
-typedef enum {
+typedef enum { /*< since=1.12 >*/
     QMI_PDS_OPERATING_MODE_STANDALONE  = 0,
     QMI_PDS_OPERATING_MODE_MS_BASED    = 1,
     QMI_PDS_OPERATING_MODE_MS_ASSISTED = 2,
 } QmiPdsOperatingMode;
 
-/**
- * qmi_pds_operating_mode_get_string:
- *
- * Since: 1.12
- */
-
 /*****************************************************************************/
 /* Helper enums for the 'QMI PDS Get AGPS Config' request/response */
 
@@ -221,15 +192,9 @@ typedef enum {
  *
  * Since: 1.12
  */
-typedef enum {
+typedef enum { /*< since=1.12 >*/
     QMI_PDS_NETWORK_MODE_UMTS = 0,
     QMI_PDS_NETWORK_MODE_CDMA = 1,
 } QmiPdsNetworkMode;
 
-/**
- * qmi_pds_network_mode_get_string:
- *
- * Since: 1.12
- */
-
 #endif /* _LIBQMI_GLIB_QMI_ENUMS_PDS_H_ */
