@@ -60,10 +60,10 @@ typedef enum { /*< since=1.10 >*/
  * @QMI_WDA_DATA_AGGREGATION_PROTOCOL_MBIM: MBIM enabled.
  * @QMI_WDA_DATA_AGGREGATION_PROTOCOL_RNDIS: RNDIS enabled.
  * @QMI_WDA_DATA_AGGREGATION_PROTOCOL_QMAP: QMAP enabled.
- * @QMI_WDA_DATA_AGGREGATION_PROTOCOL_QMAPV2: QMAPV2 enabled. Since: 1.30.
- * @QMI_WDA_DATA_AGGREGATION_PROTOCOL_QMAPV3: QMAPV3 enabled. Since: 1.30.
- * @QMI_WDA_DATA_AGGREGATION_PROTOCOL_QMAPV4: QMAPV4 enabled. Since: 1.30.
- * @QMI_WDA_DATA_AGGREGATION_PROTOCOL_QMAPV5: QMAPV5 enabled. Since: 1.28.
+ * @QMI_WDA_DATA_AGGREGATION_PROTOCOL_QMAPV2: QMAPV2 enabled. Since 1.30.
+ * @QMI_WDA_DATA_AGGREGATION_PROTOCOL_QMAPV3: QMAPV3 enabled. Since 1.30.
+ * @QMI_WDA_DATA_AGGREGATION_PROTOCOL_QMAPV4: QMAPV4 enabled. Since 1.30.
+ * @QMI_WDA_DATA_AGGREGATION_PROTOCOL_QMAPV5: QMAPV5 enabled. Since 1.28.
  *
  * Data aggregation protocol in uplink or downlink.
  *
@@ -82,4 +82,18 @@ typedef enum { /*< since=1.10 >*/
     QMI_WDA_DATA_AGGREGATION_PROTOCOL_QMAPV5   = 0x09,
 } QmiWdaDataAggregationProtocol;
 
+/**
+ * QmiWdaLoopBackState:
+ * @QMI_WDA_LOOPBACK_DISABLED: Disabled.
+ * @QMI_WDA_LOOPBACK_ENABLED: Enabled.
+ *
+ * Loopback configuration state.
+ *
+ * Since: 1.36
+ */
+typedef enum { /*< since=1.36 >*/
+    QMI_WDA_LOOPBACK_DISABLED = 0x00,
+    QMI_WDA_LOOPBACK_ENABLED  = 0x01,
+} QmiWdaLoopBackState;
+
 #endif /* _LIBQMI_GLIB_QMI_ENUMS_WDA_H_ */
