@@ -30,6 +30,8 @@
 
 /**
  * SECTION: qmi-enums
+ * @title: Common enumerations and flags
+ * @short_description: Common enumerations and flags in the library.
  *
  * This section defines common enumerations and flags used in the interface.
  */
@@ -50,41 +52,46 @@
  * @QMI_SERVICE_CAT2: Card Application Toolkit service (v2).
  * @QMI_SERVICE_UIM: User Identity Module service.
  * @QMI_SERVICE_PBM: Phonebook Management service.
- * @QMI_SERVICE_QCHAT: QCHAT service. Since: 1.8.
+ * @QMI_SERVICE_QCHAT: QCHAT service. Since 1.8.
  * @QMI_SERVICE_RMTFS: Remote file system service.
- * @QMI_SERVICE_TEST: Test service. Since: 1.8.
+ * @QMI_SERVICE_TEST: Test service. Since 1.8.
  * @QMI_SERVICE_LOC: Location service (~ PDS v2).
- * @QMI_SERVICE_SAR: Service access proxy service.
- * @QMI_SERVICE_IMS: IMS settings service. Since: 1.8.
- * @QMI_SERVICE_ADC: Analog to digital converter driver service. Since: 1.8.
- * @QMI_SERVICE_CSD: Core sound driver service. Since: 1.8.
- * @QMI_SERVICE_MFS: Modem embedded file system service. Since: 1.8.
- * @QMI_SERVICE_TIME: Time service. Since: 1.8.
- * @QMI_SERVICE_TS: Thermal sensors service. Since: 1.8.
- * @QMI_SERVICE_TMD: Thermal mitigation device service. Since: 1.8.
- * @QMI_SERVICE_SAP: Service access proxy service. Since: 1.8.
- * @QMI_SERVICE_WDA: Wireless data administrative service. Since: 1.8.
- * @QMI_SERVICE_TSYNC: TSYNC control service. Since: 1.8.
- * @QMI_SERVICE_RFSA: Remote file system access service. Since: 1.8.
- * @QMI_SERVICE_CSVT: Circuit switched videotelephony service. Since: 1.8.
- * @QMI_SERVICE_QCMAP: Qualcomm mobile access point service. Since: 1.8.
- * @QMI_SERVICE_IMSP: IMS presence service. Since: 1.8.
- * @QMI_SERVICE_IMSVT: IMS videotelephony service. Since: 1.8.
- * @QMI_SERVICE_IMSA: IMS application service. Since: 1.8.
- * @QMI_SERVICE_COEX: Coexistence service. Since: 1.8.
- * @QMI_SERVICE_PDC: Persistent device configuration service. Since: 1.8.
- * @QMI_SERVICE_STX: Simultaneous transmit service. Since: 1.8.
- * @QMI_SERVICE_BIT: Bearer independent transport service. Since: 1.8.
- * @QMI_SERVICE_IMSRTP: IMS RTP service. Since: 1.8.
- * @QMI_SERVICE_RFRPE: RF radiated performance enhancement service. Since: 1.8.
- * @QMI_SERVICE_DSD: Data system determination service. Since: 1.8.
- * @QMI_SERVICE_SSCTL: Subsystem control service. Since: 1.8.
+ * @QMI_SERVICE_SAR: Specific absorption rate service.
+ * @QMI_SERVICE_IMS: IMS settings service. Since 1.8.
+ * @QMI_SERVICE_ADC: Analog to digital converter driver service. Since 1.8.
+ * @QMI_SERVICE_CSD: Core sound driver service. Since 1.8.
+ * @QMI_SERVICE_MFS: Modem embedded file system service. Since 1.8.
+ * @QMI_SERVICE_TIME: Time service. Since 1.8.
+ * @QMI_SERVICE_TS: Thermal sensors service. Since 1.8.
+ * @QMI_SERVICE_TMD: Thermal mitigation device service. Since 1.8.
+ * @QMI_SERVICE_SAP: Service access proxy service. Since 1.8.
+ * @QMI_SERVICE_WDA: Wireless data administrative service. Since 1.8.
+ * @QMI_SERVICE_TSYNC: TSYNC control service. Since 1.8.
+ * @QMI_SERVICE_RFSA: Remote file system access service. Since 1.8.
+ * @QMI_SERVICE_CSVT: Circuit switched videotelephony service. Since 1.8.
+ * @QMI_SERVICE_QCMAP: Qualcomm mobile access point service. Since 1.8.
+ * @QMI_SERVICE_IMSP: IMS presence service. Since 1.8.
+ * @QMI_SERVICE_IMSVT: IMS videotelephony service. Since 1.8.
+ * @QMI_SERVICE_IMSA: IMS application service. Since 1.8.
+ * @QMI_SERVICE_COEX: Coexistence service. Since 1.8.
+ * @QMI_SERVICE_PDC: Persistent device configuration service. Since 1.8.
+ * @QMI_SERVICE_STX: Simultaneous transmit service. Since 1.8.
+ * @QMI_SERVICE_BIT: Bearer independent transport service. Since 1.8.
+ * @QMI_SERVICE_IMSRTP: IMS RTP service. Since 1.8.
+ * @QMI_SERVICE_RFRPE: RF radiated performance enhancement service. Since 1.8.
+ * @QMI_SERVICE_DSD: Data system determination service. Since 1.8.
+ * @QMI_SERVICE_SSCTL: Subsystem control service. Since 1.8.
+ * @QMI_SERVICE_DPM: Data Port Mapper service. Since 1.30.
  * @QMI_SERVICE_CAT: Card Application Toolkit service (v1).
  * @QMI_SERVICE_RMS: Remote Management Service.
  * @QMI_SERVICE_OMA: Open Mobile Alliance device management service.
- * @QMI_SERVICE_FOTA: Firmware Over The Air service. Since: 1.24.
- * @QMI_SERVICE_GMS: Telit General Modem Service. Since: 1.24.
- * @QMI_SERVICE_GAS: Telit General Application Service. Since: 1.24.
+ * @QMI_SERVICE_FOX: Foxconn General Modem Service. Since 1.32.
+ * @QMI_SERVICE_SSC: Snapdragon Sensore Core Service. Since 1.34.
+ * @QMI_SERVICE_FOTA: Firmware Over The Air service. Since 1.24.
+ * @QMI_SERVICE_GMS: Telit General Modem Service. Since 1.24.
+ * @QMI_SERVICE_GAS: Telit General Application Service. Since 1.24.
+ * @QMI_SERVICE_ATR: Telit AT Relay Service. Since 1.34.
+ * @QMI_SERVICE_IMSDCM: IMS dcm. Since 1.37.
  *
  * QMI services.
  *
@@ -136,12 +143,17 @@ typedef enum { /*< since=1.0 >*/
     QMI_SERVICE_RFRPE   = 0x29,
     QMI_SERVICE_DSD     = 0x2A,
     QMI_SERVICE_SSCTL   = 0x2B,
+    QMI_SERVICE_DPM     = 0x2F,
     QMI_SERVICE_CAT     = 0xE0,
     QMI_SERVICE_RMS     = 0xE1,
     QMI_SERVICE_OMA     = 0xE2,
+    QMI_SERVICE_FOX     = 0xE3,
     QMI_SERVICE_FOTA    = 0xE6,
     QMI_SERVICE_GMS     = 0xE7,
     QMI_SERVICE_GAS     = 0xE8,
+    QMI_SERVICE_ATR     = 0xED,
+    QMI_SERVICE_SSC     = 0x190,
+    QMI_SERVICE_IMSDCM  = 0x302,
 } QmiService;
 
 /**
@@ -160,20 +172,26 @@ typedef enum { /*< since=1.28 >*/   /* the get_string() helper and QmiEndian typ
 
 /**
  * QmiDataEndpointType:
- * @QMI_DATA_ENDPOINT_TYPE_HSUSB: Data Endpoint Type HSUSB.
- * @QMI_DATA_ENDPOINT_TYPE_PCIE: Data Endpoint Type PCIE. Since: 1.28.
- * @QMI_DATA_ENDPOINT_TYPE_EMBEDDED: Data Endpoint Type embedded. Since 1.28.
- * @QMI_DATA_ENDPOINT_TYPE_UNDEFINED: Data Endpoint Type undefined.
+ * @QMI_DATA_ENDPOINT_TYPE_UNKNOWN: Unknown. Since 1.30.
+ * @QMI_DATA_ENDPOINT_TYPE_HSIC: High-speed inter-chip interface. Since 1.30.
+ * @QMI_DATA_ENDPOINT_TYPE_HSUSB: High-speed USB.
+ * @QMI_DATA_ENDPOINT_TYPE_PCIE: PCIe. Since 1.28.
+ * @QMI_DATA_ENDPOINT_TYPE_EMBEDDED: Embedded. Since 1.28.
+ * @QMI_DATA_ENDPOINT_TYPE_BAM_DMUX: BAM/DMUX. Since 1.30.
+ * @QMI_DATA_ENDPOINT_TYPE_UNDEFINED: Undefined.
  *
  * Data Endpoint Type.
  *
  * Since: 1.18
  */
 typedef enum { /*< since=1.18 >*/
-    QMI_DATA_ENDPOINT_TYPE_HSUSB     = 0X02,
-    QMI_DATA_ENDPOINT_TYPE_PCIE      = 0X03,
-    QMI_DATA_ENDPOINT_TYPE_EMBEDDED  = 0X04,
-    QMI_DATA_ENDPOINT_TYPE_UNDEFINED = 0XFF,
+    QMI_DATA_ENDPOINT_TYPE_UNKNOWN   = 0x00,
+    QMI_DATA_ENDPOINT_TYPE_HSIC      = 0x01,
+    QMI_DATA_ENDPOINT_TYPE_HSUSB     = 0x02,
+    QMI_DATA_ENDPOINT_TYPE_PCIE      = 0x03,
+    QMI_DATA_ENDPOINT_TYPE_EMBEDDED  = 0x04,
+    QMI_DATA_ENDPOINT_TYPE_BAM_DMUX  = 0x05,
+    QMI_DATA_ENDPOINT_TYPE_UNDEFINED = 0xFF,
 } QmiDataEndpointType;
 
 /**
@@ -206,4 +224,24 @@ typedef enum { /*< since=1.28 >*/
     QMI_SIO_PORT_A2_MUX_RMNET7 = 0x0e0b,
 } QmiSioPort;
 
+/**
+ * QmiSubscriptionType:
+ * @QMI_SUBSCRIPTION_TYPE_DEFAULT: Default.
+ * @QMI_SUBSCRIPTION_TYPE_PRIMARY: Primary
+ * @QMI_SUBSCRIPTION_TYPE_SECONDARY: Secondary.
+ * @QMI_SUBSCRIPTION_TYPE_TERITIARY: Teritiary.
+ * @QMI_SUBSCRIPTION_TYPE_ANY: Any.
+ *
+ * Subscription Type
+ *
+ * Since: 1.37
+ */
+typedef enum { /*< since=1.37 >*/
+    QMI_SUBSCRIPTION_TYPE_DEFAULT     = 0x00,
+    QMI_SUBSCRIPTION_TYPE_PRIMARY     = 0x01,
+    QMI_SUBSCRIPTION_TYPE_SECONDARY   = 0x02,
+    QMI_SUBSCRIPTION_TYPE_TERITIARY   = 0x03,
+    QMI_SUBSCRIPTION_TYPE_ANY         = 0xff,
+} QmiSubscriptionType;
+
 #endif /* _LIBQMI_GLIB_QMI_ENUMS_H_ */
