@@ -66,6 +66,9 @@
 #include "qmi-fox.h"
 #include "qmi-atr.h"
 #include "qmi-ssc.h"
+#include "qmi-ims.h"
+#include "qmi-imsa.h"
+#include "qmi-imsp.h"
 
 #define PACKED __attribute__((packed))
 
@@ -529,10 +532,10 @@ qmi_message_new_from_data (QmiService   service,
      * with enough room to copy the rest of the message into */
     if (service == QMI_SERVICE_CTL) {
         message_len = sizeof (struct control_header) +
-            ((struct control_message *)(qmi_data->data))->header.tlv_length;
+            GUINT16_FROM_LE (((struct control_message *)(qmi_data->data))->header.tlv_length);
     } else {
         message_len = sizeof (struct service_header) +
-            ((struct service_message *)(qmi_data->data))->header.tlv_length;
+            GUINT16_FROM_LE (((struct service_message *)(qmi_data->data))->header.tlv_length);
     }
 
     /* Use the size of qmux_header for both QMUX and QRTR as they are the same */
@@ -929,6 +932,44 @@ qmi_message_tlv_write_sized_guint (QmiMessage  *self,
     return TRUE;
 }
 
+gboolean
+qmi_message_tlv_write_gfloat (QmiMessage  *self,
+                              QmiEndian    endian,
+                              gfloat       in,
+                              GError     **error)
+{
+    gfloat tmp;
+
+    g_return_val_if_fail (self != NULL, FALSE);
+
+    /* Check for overflow of message size */
+    if (!tlv_error_if_write_overflow (self, sizeof (in), error))
+        return FALSE;
+
+    tmp = (endian == QMI_ENDIAN_BIG ? QMI_GFLOAT_TO_BE (in) : QMI_GFLOAT_TO_LE (in));
+    g_byte_array_append (self, (guint8 *)&tmp, sizeof (tmp));
+    return TRUE;
+}
+
+gboolean
+qmi_message_tlv_write_gdouble (QmiMessage  *self,
+                               QmiEndian    endian,
+                               gdouble       in,
+                               GError     **error)
+{
+    gdouble tmp;
+
+    g_return_val_if_fail (self != NULL, FALSE);
+
+    /* Check for overflow of message size */
+    if (!tlv_error_if_write_overflow (self, sizeof (in), error))
+        return FALSE;
+
+    tmp = (endian == QMI_ENDIAN_BIG ? QMI_GDOUBLE_TO_BE (in) : QMI_GDOUBLE_TO_LE (in));
+    g_byte_array_append (self, (guint8 *)&tmp, sizeof (tmp));
+    return TRUE;
+}
+
 gboolean
 qmi_message_tlv_write_string (QmiMessage   *self,
                               guint8        n_size_prefix_bytes,
@@ -1833,6 +1874,7 @@ qmi_message_get_printable_full (QmiMessage        *self,
 #if defined HAVE_QMI_SERVICE_ATR
         contents = __qmi_message_atr_get_printable (self, context, line_prefix);
 #endif
+        break;
     case QMI_SERVICE_IMSP:
 #if defined HAVE_QMI_SERVICE_IMSP
         contents = __qmi_message_imsp_get_printable (self, context, line_prefix);
@@ -1841,6 +1883,11 @@ qmi_message_get_printable_full (QmiMessage        *self,
     case QMI_SERVICE_IMSA:
 #if defined HAVE_QMI_SERVICE_IMSA
         contents = __qmi_message_imsa_get_printable (self, context, line_prefix);
+#endif
+        break;
+    case QMI_SERVICE_IMSDCM:
+#if defined HAVE_QMI_SERVICE_IMSDCM
+        contents = __qmi_message_imsdcm_get_printable (self, context, line_prefix);
 #endif
         break;
     case QMI_SERVICE_IMS:
@@ -1968,6 +2015,7 @@ __qmi_message_is_abortable (QmiMessage        *self,
     case QMI_SERVICE_FOX:
     case QMI_SERVICE_ATR:
     case QMI_SERVICE_SSC:
+    case QMI_SERVICE_IMSDCM:
     default:
         return FALSE;
     }
