@@ -90,8 +90,12 @@ test_message_parse_common (const guint8 *buffer,
 
         message = qmi_message_new_from_raw (array, &error);
         if (!message) {
-            if (error && (n_messages < n_expected_messages))
-                g_printerr ("error creating message from raw data: '%s'\n", error->message);
+            if (error) {
+                if (n_messages < n_expected_messages)
+                    g_printerr ("error creating message from raw data: '%s'\n", error->message);
+                else
+                    g_debug ("error creating message from raw data: '%s'", error->message);
+            }
             break;
         }
 
@@ -104,6 +108,22 @@ test_message_parse_common (const guint8 *buffer,
     g_assert_cmpuint (n_messages, ==, n_expected_messages);
 }
 
+static void
+test_message_parse_wrong_qmux (void)
+{
+    const guint8 buffer[] = { 0x00, 0x00, 0x00, 0x00, 0x00, 0x0a };
+
+    test_message_parse_common (buffer, sizeof (buffer), 0);
+}
+
+static void
+test_message_parse_tiny (void)
+{
+    const guint8 buffer[] = { 0x01, 0x00, 0x02 };
+
+    test_message_parse_common (buffer, sizeof (buffer), 0);
+}
+
 static void
 test_message_parse_short (void)
 {
@@ -314,6 +334,53 @@ test_message_parse_signed_int (void)
 
 #endif
 
+static void
+test_message_parse_empty_fixed_string (void)
+{
+    /* NAS response: Get System Info
+     * If the "Network ID Valid" field is false, then the MCC/MNC fields will
+     * contain all zeros. Make sure that's printed as an empty string and not
+     * an error.
+     */
+    const guint8 buffer[] = {
+        0x01,       /* marker */
+        0x2C, 0x00, /* qmux length */
+        0x80,       /* qmux flags */
+        0x03,       /* service: NAS */
+        0x03,       /* client */
+        0x02,       /* service flags: Response */
+        0x01, 0x00, /* transaction */
+        0x4D, 0x00, /* message: Get System Info */
+        0x20, 0x00, /* all tlvs length: 4 bytes */
+        /* TLV */
+        0x19,       /* type: LTE System Info v2 */
+        0x1D, 0x00, /* length: 29 bytes */
+        0x01,       /* Domain Valid */
+        0x04,       /* Domain */
+        0x01,       /* Service Capability Valid */
+        0x02,       /* Service Capability */
+        0x01,       /* Roaming Status Valid */
+        0x00,       /* Roaming Status */
+        0x01,       /* Forbidden Valid */
+        0x00,       /* Forbidden */
+        0x00,       /* LAC Valid */
+        0x00,0x00,  /* LAC */
+        0x01,       /* CID Valid */
+        0x0C, 0xF6, 0xE7, 0x02, /* CID */
+        0x01,       /* Registration Reject Info Valid */
+        0x02,       /* Registration Reject Domain */
+        0x0F,       /* Registration Reject Cause */
+        0x00,       /* Network ID Valid */
+        0x00, 0x00, 0x00, /* MCC */
+        0x00, 0x00, 0x00, /* MNC */
+        0x01,       /* TAC Valid */
+        0x4D, 0xBE  /* TAC */
+    };
+
+    test_message_printable_common (buffer, sizeof (buffer), QMI_MESSAGE_VENDOR_GENERIC, "mcc = '' mnc = ''");
+}
+
+
 /*****************************************************************************/
 
 static void
@@ -1597,10 +1664,81 @@ test_message_set_transaction_id_services (void)
 
 /*****************************************************************************/
 
+static void
+test_message_16bit_service_indication (void)
+{
+    g_autoptr(GByteArray) buffer = NULL;
+    g_autoptr(QmiMessage) message = NULL;
+    g_autoptr(GError)     error = NULL;
+
+    const guint8 ssc_message[] = {
+        0x02,       /* marker is the QRTR one because we have a 16bit service! */
+        0x21, 0x00, /* message length: 33 bytes*/
+        0x90, 0x01, /* service: SSC */
+        0x03,       /* client */
+        0x04,       /* service flags: Indication */
+        0x01, 0x00, /* transaction */
+        0x21, 0x00, /* message: Report Small */
+        0x15, 0x00, /* all tlvs length: 21 bytes */
+        /* TLV */
+        0x01,                   /* type: client id */
+        0x08, 0x00,             /* length: 8 bytes */
+        0x01, 0x00, 0x00, 0x00, /* 64bit uint value */
+        0x00, 0x00, 0x00, 0x00,
+        /* TLV */
+        0x02,                         /* type: data */
+        0x07, 0x00,                   /* length: 7 bytes */
+        0x05, 0x00,                   /* array size */
+        0x00, 0x01, 0x02, 0x03, 0x04, /* 5 bytes in data array */
+    };
+
+    test_message_printable_common (ssc_message, sizeof (ssc_message), QMI_MESSAGE_VENDOR_GENERIC, "");
+
+    /* DMS message */
+    buffer = g_byte_array_append (g_byte_array_sized_new (sizeof (ssc_message)), ssc_message, sizeof (ssc_message));
+    message = qmi_message_new_from_raw (buffer, &error);
+    g_assert_no_error (error);
+    g_assert (message);
+
+    g_assert (qmi_message_is_indication (message));
+    g_assert_cmpuint (qmi_message_get_service (message), ==, QMI_SERVICE_SSC);
+    g_assert_cmpuint (qmi_message_get_message_id (message), ==, 0x0021);
+
+#if defined HAVE_QMI_INDICATION_SSC_REPORT_SMALL
+    {
+        g_autoptr(QmiIndicationSscReportSmallOutput) output = NULL;
+        gboolean      tlv_exists;
+        GArray       *value_data;
+        guint64       client_id;
+        const guint8  expected_value_data[] = {
+            0x00, 0x01, 0x02, 0x03, 0x04
+        };
+
+        output = qmi_indication_ssc_report_small_indication_parse (message, &error);
+        g_assert_no_error (error);
+        g_assert (output);
+
+        tlv_exists = qmi_indication_ssc_report_small_output_get_client_id (output, &client_id, &error);
+        g_assert_no_error (error);
+        g_assert (tlv_exists);
+        g_assert_cmpuint (client_id, ==, (guint64)0x01);
+
+        tlv_exists = qmi_indication_ssc_report_small_output_get_data (output, &value_data, &error);
+        g_assert_no_error (error);
+        g_assert (tlv_exists);
+        _g_assert_cmpmem (value_data->data, value_data->len, expected_value_data, G_N_ELEMENTS (expected_value_data));
+    }
+#endif
+}
+
+/*****************************************************************************/
+
 int main (int argc, char **argv)
 {
     g_test_init (&argc, &argv, NULL);
 
+    g_test_add_func ("/libqmi-glib/message/parse/wrong-qmux",            test_message_parse_wrong_qmux);
+    g_test_add_func ("/libqmi-glib/message/parse/tiny",                  test_message_parse_tiny);
     g_test_add_func ("/libqmi-glib/message/parse/short",                 test_message_parse_short);
     g_test_add_func ("/libqmi-glib/message/parse/complete",              test_message_parse_complete);
     g_test_add_func ("/libqmi-glib/message/parse/complete-and-short",    test_message_parse_complete_and_short);
@@ -1621,6 +1759,7 @@ int main (int argc, char **argv)
 #if defined HAVE_QMI_MESSAGE_NAS_SWI_GET_STATUS
     g_test_add_func ("/libqmi-glib/message/parse/signed-int", test_message_parse_signed_int);
 #endif
+    g_test_add_func ("/libqmi-glib/message/parse/empty-fixed-string", test_message_parse_empty_fixed_string);
 
     g_test_add_func ("/libqmi-glib/message/new/request",           test_message_new_request);
     g_test_add_func ("/libqmi-glib/message/new/request-from-data", test_message_new_request_from_data);
@@ -1643,5 +1782,7 @@ int main (int argc, char **argv)
     g_test_add_func ("/libqmi-glib/message/set-transaction-id/ctl",      test_message_set_transaction_id_ctl);
     g_test_add_func ("/libqmi-glib/message/set-transaction-id/services", test_message_set_transaction_id_services);
 
+    g_test_add_func ("/libqmi-glib/message/16bit-service/indication", test_message_16bit_service_indication);
+
     return g_test_run ();
 }
