@@ -27,35 +27,35 @@
 #include <libqmi-glib.h>
 
 #include "qfu-device-selection.h"
-#include "qfu-udev-helpers.h"
+#include "qfu-helpers.h"
 
 G_DEFINE_TYPE (QfuDeviceSelection, qfu_device_selection, G_TYPE_OBJECT)
 
 struct _QfuDeviceSelectionPrivate {
     /* inputs */
-    gchar   *preferred_devices[QFU_UDEV_HELPER_DEVICE_TYPE_LAST];
+    gchar   *preferred_devices[QFU_HELPERS_DEVICE_TYPE_LAST];
     guint16  preferred_vid;
     guint16  preferred_pid;
     guint    preferred_busnum;
     guint    preferred_devnum;
 
-#if defined WITH_UDEV
     /* sysfs path */
     gchar   *sysfs_path;
     /* peer port sysfs path */
     gchar   *peer_port;
+
+#if defined WITH_UDEV
     /* generic udev monitor */
-    QfuUdevHelperGenericMonitor *monitor;
+    QfuHelpersUdevGenericMonitor *monitor;
 #endif
 };
 
 /******************************************************************************/
 
-#if defined WITH_UDEV
-
 static GFile *
-device_selection_get_single (QfuDeviceSelection      *self,
-                             QfuUdevHelperDeviceType  device_type)
+device_selection_get_single (QfuDeviceSelection   *self,
+                             QfuHelpersDeviceType  device_type,
+                             QfuHelpersDeviceMode  device_mode)
 {
     GFile *first_selection = NULL;
     GFile *preferred_selection = NULL;
@@ -63,10 +63,10 @@ device_selection_get_single (QfuDeviceSelection      *self,
     gchar *path;
 
     g_debug ("[qfu,device-selection] single %s device requested in sysfs path '%s'",
-             qfu_udev_helper_device_type_to_string (device_type),
+             qfu_helpers_device_type_to_string (device_type),
              self->priv->sysfs_path);
 
-    list = qfu_udev_helper_list_devices (device_type, self->priv->sysfs_path);
+    list = qfu_helpers_list_devices (device_type, device_mode, self->priv->sysfs_path);
     for (l = list; l; l = g_list_next (l)) {
         path = g_file_get_path (G_FILE (l->data));
         g_debug ("[qfu,device-selection]   device found: %s", path);
@@ -76,7 +76,7 @@ device_selection_get_single (QfuDeviceSelection      *self,
             preferred_selection = g_object_ref (l->data);
         g_free (path);
     }
-    g_list_free_full (list, (GDestroyNotify) g_object_unref);
+    g_list_free_full (list, g_object_unref);
 
     if (preferred_selection) {
         path = g_file_get_path (preferred_selection);
@@ -98,51 +98,35 @@ device_selection_get_single (QfuDeviceSelection      *self,
     return NULL;
 }
 
-#else
-
-static GFile *
-device_selection_get_single (QfuDeviceSelection      *self,
-                             QfuUdevHelperDeviceType  device_type)
-{
-
-    if (!self->priv->preferred_devices[device_type]) {
-        g_warning ("[qfu,device-selection] no %s device defined", qfu_udev_helper_device_type_to_string (device_type));
-        return NULL;
-    }
-
-    return g_file_new_for_commandline_arg (self->priv->preferred_devices[device_type]);
-}
-
-#endif
-
 GFile *
 qfu_device_selection_get_single_cdc_wdm (QfuDeviceSelection *self)
 {
-    return device_selection_get_single (self, QFU_UDEV_HELPER_DEVICE_TYPE_CDC_WDM);
+    return device_selection_get_single (self, QFU_HELPERS_DEVICE_TYPE_CDC_WDM, QFU_HELPERS_DEVICE_MODE_MODEM);
 }
 
 GFile *
-qfu_device_selection_get_single_tty (QfuDeviceSelection *self)
+qfu_device_selection_get_single_tty (QfuDeviceSelection   *self,
+                                     QfuHelpersDeviceMode  mode)
 {
-    return device_selection_get_single (self, QFU_UDEV_HELPER_DEVICE_TYPE_TTY);
+    return device_selection_get_single (self, QFU_HELPERS_DEVICE_TYPE_TTY, mode);
 }
 
 /******************************************************************************/
-#if defined WITH_UDEV
 
 static GList *
-device_selection_get_multiple (QfuDeviceSelection      *self,
-                               QfuUdevHelperDeviceType  device_type)
+device_selection_get_multiple (QfuDeviceSelection   *self,
+                               QfuHelpersDeviceType  device_type,
+                               QfuHelpersDeviceMode  device_mode)
 {
     GFile *preferred_selection = NULL;
     GList *list, *l;
     gchar *path;
 
     g_debug ("[qfu,device-selection] multiple %s devices requested in sysfs path '%s'",
-             qfu_udev_helper_device_type_to_string (device_type),
+             qfu_helpers_device_type_to_string (device_type),
              self->priv->sysfs_path);
 
-    list = qfu_udev_helper_list_devices (device_type, self->priv->sysfs_path);
+    list = qfu_helpers_list_devices (device_type, device_mode, self->priv->sysfs_path);
     for (l = list; l; l = g_list_next (l)) {
         path = g_file_get_path (G_FILE (l->data));
         g_debug ("[qfu,device-selection]   device found: %s", path);
@@ -156,7 +140,7 @@ device_selection_get_multiple (QfuDeviceSelection      *self,
         path = g_file_get_path (preferred_selection);
         g_debug ("[qfu,device-selection]   using only preferred device: %s", path);
         g_free (path);
-        g_list_free_full (list, (GDestroyNotify) g_object_unref);
+        g_list_free_full (list, g_object_unref);
         return g_list_append (NULL, preferred_selection);
     }
 
@@ -167,25 +151,15 @@ device_selection_get_multiple (QfuDeviceSelection      *self,
     return NULL;
 }
 
-#endif
-
 GList *
-qfu_device_selection_get_multiple_ttys (QfuDeviceSelection *self)
+qfu_device_selection_get_multiple_ttys (QfuDeviceSelection   *self,
+                                        QfuHelpersDeviceMode  mode)
 {
-#if defined WITH_UDEV
-    return device_selection_get_multiple (self, QFU_UDEV_HELPER_DEVICE_TYPE_TTY);
-#else
-    GFile *single;
-
-    single = qfu_device_selection_get_single_tty (self);
-    return (single ? g_list_append (NULL, single) : NULL);
-#endif
+    return device_selection_get_multiple (self, QFU_HELPERS_DEVICE_TYPE_TTY, mode);
 }
 
 /******************************************************************************/
 
-#if defined WITH_UDEV
-
 GFile *
 qfu_device_selection_wait_for_cdc_wdm_finish (QfuDeviceSelection  *self,
                                               GAsyncResult        *res,
@@ -210,11 +184,11 @@ wait_for_device_ready (gpointer      unused,
     GError *error = NULL;
     GFile  *file;
 
-    file = qfu_udev_helper_wait_for_device_finish (res, &error);
+    file = qfu_helpers_wait_for_device_finish (res, &error);
     if (!file)
         g_task_return_error (task, error);
     else
-        g_task_return_pointer (task, file, (GDestroyNotify) g_object_unref);
+        g_task_return_pointer (task, file, g_object_unref);
     g_object_unref (task);
 }
 
@@ -227,16 +201,18 @@ qfu_device_selection_wait_for_cdc_wdm (QfuDeviceSelection  *self,
     GTask *task;
 
     task = g_task_new (self, cancellable, callback, user_data);
-    qfu_udev_helper_wait_for_device (QFU_UDEV_HELPER_DEVICE_TYPE_CDC_WDM,
-                                     self->priv->sysfs_path,
-                                     self->priv->peer_port,
-                                     cancellable,
-                                     (GAsyncReadyCallback) wait_for_device_ready,
-                                     task);
+    qfu_helpers_wait_for_device (QFU_HELPERS_DEVICE_TYPE_CDC_WDM,
+                                 QFU_HELPERS_DEVICE_MODE_MODEM,
+                                 self->priv->sysfs_path,
+                                 self->priv->peer_port,
+                                 cancellable,
+                                 (GAsyncReadyCallback) wait_for_device_ready,
+                                 task);
 }
 
 void
 qfu_device_selection_wait_for_tty (QfuDeviceSelection  *self,
+                                   QfuHelpersDeviceMode mode,
                                    GCancellable        *cancellable,
                                    GAsyncReadyCallback  callback,
                                    gpointer             user_data)
@@ -244,16 +220,15 @@ qfu_device_selection_wait_for_tty (QfuDeviceSelection  *self,
     GTask *task;
 
     task = g_task_new (self, cancellable, callback, user_data);
-    qfu_udev_helper_wait_for_device (QFU_UDEV_HELPER_DEVICE_TYPE_TTY,
-                                     self->priv->sysfs_path,
-                                     self->priv->peer_port,
-                                     cancellable,
-                                     (GAsyncReadyCallback) wait_for_device_ready,
-                                     task);
+    qfu_helpers_wait_for_device (QFU_HELPERS_DEVICE_TYPE_TTY,
+                                 mode,
+                                 self->priv->sysfs_path,
+                                 self->priv->peer_port,
+                                 cancellable,
+                                 (GAsyncReadyCallback) wait_for_device_ready,
+                                 task);
 }
 
-#endif
-
 /******************************************************************************/
 
 QfuDeviceSelection *
@@ -291,34 +266,32 @@ qfu_device_selection_new (const gchar  *preferred_cdc_wdm,
     self = g_object_new (QFU_TYPE_DEVICE_SELECTION, NULL);
 
     /* Store inputs */
-    self->priv->preferred_devices[QFU_UDEV_HELPER_DEVICE_TYPE_CDC_WDM] = g_strdup (preferred_cdc_wdm);
-    self->priv->preferred_devices[QFU_UDEV_HELPER_DEVICE_TYPE_TTY]     = g_strdup (preferred_tty);
+    self->priv->preferred_devices[QFU_HELPERS_DEVICE_TYPE_CDC_WDM] = g_strdup (preferred_cdc_wdm);
+    self->priv->preferred_devices[QFU_HELPERS_DEVICE_TYPE_TTY]     = g_strdup (preferred_tty);
     self->priv->preferred_vid     = preferred_vid;
     self->priv->preferred_pid     = preferred_pid;
     self->priv->preferred_busnum  = preferred_busnum;
     self->priv->preferred_devnum  = preferred_devnum;
 
-#if defined WITH_UDEV
-    {
-        /* Initialize sysfs path from inputs */
-        if (preferred_vid || preferred_devnum)
-            self->priv->sysfs_path = qfu_udev_helper_find_by_device_info (preferred_vid, preferred_pid, preferred_busnum, preferred_devnum, error);
-        else if (preferred_cdc_wdm || preferred_tty)
-            self->priv->sysfs_path = qfu_udev_helper_find_by_file_path (preferred_cdc_wdm ? preferred_cdc_wdm : preferred_tty, error);
-        else
-            g_assert_not_reached ();
+    /* Initialize sysfs path from inputs */
+    if (preferred_vid || preferred_devnum)
+        self->priv->sysfs_path = qfu_helpers_find_by_device_info (preferred_vid, preferred_pid, preferred_busnum, preferred_devnum, error);
+    else if (preferred_cdc_wdm || preferred_tty)
+        self->priv->sysfs_path = qfu_helpers_find_by_file_path (preferred_cdc_wdm ? preferred_cdc_wdm : preferred_tty, error);
+    else
+        g_assert_not_reached ();
 
-        if (!self->priv->sysfs_path) {
-            g_object_unref (self);
-            return NULL;
-        }
-
-        /* look for a peer port */
-        self->priv->peer_port = qfu_udev_helper_find_peer_port (self->priv->sysfs_path, error);
-
-        /* Initialize right away the generic udev monitor for this sysfs path */
-        self->priv->monitor = qfu_udev_helper_generic_monitor_new (self->priv->sysfs_path);
+    if (!self->priv->sysfs_path) {
+        g_object_unref (self);
+        return NULL;
     }
+
+    /* look for a peer port */
+    self->priv->peer_port = qfu_helpers_find_peer_port (self->priv->sysfs_path, error);
+
+#if defined WITH_UDEV
+    /* Initialize right away the generic udev monitor for this sysfs path */
+    self->priv->monitor = qfu_helpers_udev_generic_monitor_new (self->priv->sysfs_path);
 #endif
 
     return self;
@@ -338,12 +311,13 @@ finalize (GObject *object)
 
 #if defined WITH_UDEV
     if (self->priv->monitor)
-        qfu_udev_helper_generic_monitor_free (self->priv->monitor);
-    g_free (self->priv->sysfs_path);
-    g_free (self->priv->peer_port);
+        qfu_helpers_udev_generic_monitor_free (self->priv->monitor);
 #endif
 
-    for (i = 0; i < QFU_UDEV_HELPER_DEVICE_TYPE_LAST; i++)
+    g_free (self->priv->sysfs_path);
+    g_free (self->priv->peer_port);
+
+    for (i = 0; i < QFU_HELPERS_DEVICE_TYPE_LAST; i++)
         g_free (self->priv->preferred_devices[i]);
 
     G_OBJECT_CLASS (qfu_device_selection_parent_class)->finalize (object);
