@@ -24,6 +24,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <locale.h>
+#include <math.h>
 #include <string.h>
 
 #include <glib.h>
@@ -64,6 +65,9 @@ typedef struct {
     guint           set_operation_mode_indication_id;
     guint           get_engine_lock_indication_id;
     guint           set_engine_lock_indication_id;
+    guint           inject_position_indication_id;
+    guint           inject_time_indication_id;
+    guint           get_predicted_orbits_data_source_indication_id;
 } Context;
 static Context *ctx;
 
@@ -84,6 +88,10 @@ static gboolean get_operation_mode_flag;
 static gchar   *set_operation_mode_str;
 static gboolean get_engine_lock_flag;
 static gchar   *set_engine_lock_str;
+static gdouble  inject_position_latitude = NAN;
+static gdouble  inject_position_longitude = NAN;
+static gboolean inject_time_flag;
+static gboolean get_predicted_orbits_data_source_flag;
 static gboolean noop_flag;
 
 #define DEFAULT_LOC_TIMEOUT_SECS 30
@@ -195,6 +203,28 @@ static GOptionEntry entries[] = {
       "Set engine lock status",
       "[none|mi|mt|all]"
     },
+#endif
+#if defined HAVE_QMI_MESSAGE_LOC_INJECT_POSITION
+    { "loc-inject-position-latitude", 0, 0, G_OPTION_ARG_DOUBLE, &inject_position_latitude,
+      "Inject latitude into GNSS engine",
+      "-90.0 to 90.0. Positive values indicate northern latitude."
+    },
+    { "loc-inject-position-longitude", 0, 0, G_OPTION_ARG_DOUBLE, &inject_position_longitude,
+      "Inject longitude into GNSS engine",
+      "-180.0 to 180.0. Positive values indicate eastern longitude."
+    },
+#endif
+#if defined HAVE_QMI_MESSAGE_LOC_INJECT_UTC_TIME
+    { "loc-inject-time", 0, 0, G_OPTION_ARG_NONE, &inject_time_flag,
+      "Inject UTC time into GNSS engine",
+      NULL
+    },
+#endif
+#if defined HAVE_QMI_MESSAGE_LOC_GET_PREDICTED_ORBITS_DATA_SOURCE
+    { "loc-get-predicted-orbits-data-source", 0, 0, G_OPTION_ARG_NONE, &get_predicted_orbits_data_source_flag,
+      "Get predicted orbits data source",
+      NULL
+    },
 #endif
     { "loc-noop", 0, 0, G_OPTION_ARG_NONE, &noop_flag,
       "Just allocate or release a LOC client. Use with `--client-no-release-cid' and/or `--client-cid'",
@@ -247,6 +277,9 @@ qmicli_loc_options_enabled (void)
                  !!set_operation_mode_str +
                  get_engine_lock_flag +
                  !!set_engine_lock_str +
+                 (!isnan (inject_position_latitude) || !isnan (inject_position_longitude)) +
+                 inject_time_flag +
+                 get_predicted_orbits_data_source_flag +
                  noop_flag);
 
     if (n_actions > 1) {
@@ -280,7 +313,11 @@ qmicli_loc_options_enabled (void)
         get_operation_mode_flag ||
         set_operation_mode_str ||
         get_engine_lock_flag ||
-        set_engine_lock_str)
+        set_engine_lock_str ||
+        !isnan (inject_position_latitude) ||
+        !isnan (inject_position_longitude) ||
+        inject_time_flag ||
+        get_predicted_orbits_data_source_flag)
         qmicli_expect_indications ();
 
     checked = TRUE;
@@ -326,6 +363,15 @@ context_free (Context *context)
     if (context->set_engine_lock_indication_id)
         g_signal_handler_disconnect (context->client, context->set_engine_lock_indication_id);
 
+    if (context->inject_position_indication_id)
+        g_signal_handler_disconnect (context->client, context->inject_position_indication_id);
+
+    if (context->inject_time_indication_id)
+        g_signal_handler_disconnect (context->client, context->inject_time_indication_id);
+
+    if (context->get_predicted_orbits_data_source_indication_id)
+        g_signal_handler_disconnect (context->client, context->get_predicted_orbits_data_source_indication_id);
+
     g_clear_object (&context->cancellable);
     g_clear_object (&context->client);
     g_clear_object (&context->device);
@@ -871,17 +917,6 @@ delete_assistance_data_ready (QmiClientLoc *client,
         operation_shutdown (FALSE);
         return;
     }
-
-    /* Wait for response asynchronously */
-    ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
-                                             (GSourceFunc) delete_assistance_data_timed_out,
-                                             NULL);
-
-    ctx->delete_assistance_data_indication_id = g_signal_connect (ctx->client,
-                                                                  "delete-assistance-data",
-                                                                  G_CALLBACK (delete_assistance_data_received),
-                                                                  NULL);
-
     qmi_message_loc_delete_assistance_data_output_unref (output);
 }
 
@@ -943,16 +978,6 @@ get_nmea_types_ready (QmiClientLoc *client,
         operation_shutdown (FALSE);
         return;
     }
-
-    /* Wait for response asynchronously */
-    ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
-                                             (GSourceFunc) get_nmea_types_timed_out,
-                                             NULL);
-
-    ctx->get_nmea_types_indication_id = g_signal_connect (ctx->client,
-                                                          "get-nmea-types",
-                                                          G_CALLBACK (get_nmea_types_received),
-                                                          NULL);
 }
 
 #endif /* HAVE_QMI_MESSAGE_LOC_GET_NMEA_TYPES */
@@ -1004,16 +1029,6 @@ set_nmea_types_ready (QmiClientLoc *client,
         operation_shutdown (FALSE);
         return;
     }
-
-    /* Wait for response asynchronously */
-    ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
-                                             (GSourceFunc) set_nmea_types_timed_out,
-                                             NULL);
-
-    ctx->set_nmea_types_indication_id = g_signal_connect (ctx->client,
-                                                          "set-nmea-types",
-                                                          G_CALLBACK (set_nmea_types_received),
-                                                          NULL);
 }
 
 static QmiMessageLocSetNmeaTypesInput *
@@ -1093,16 +1108,6 @@ get_operation_mode_ready (QmiClientLoc *client,
         operation_shutdown (FALSE);
         return;
     }
-
-    /* Wait for response asynchronously */
-    ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
-                                             (GSourceFunc) get_operation_mode_timed_out,
-                                             NULL);
-
-    ctx->get_operation_mode_indication_id = g_signal_connect (ctx->client,
-                                                              "get-operation-mode",
-                                                              G_CALLBACK (get_operation_mode_received),
-                                                              NULL);
 }
 #endif /* HAVE_QMI_MESSAGE_LOC_GET_OPERATION_MODE */
 
@@ -1153,16 +1158,6 @@ set_operation_mode_ready (QmiClientLoc *client,
         operation_shutdown (FALSE);
         return;
     }
-
-    /* Wait for response asynchronously */
-    ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
-                                             (GSourceFunc) set_operation_mode_timed_out,
-                                             NULL);
-
-    ctx->set_operation_mode_indication_id = g_signal_connect (ctx->client,
-                                                              "set-operation-mode",
-                                                              G_CALLBACK (set_operation_mode_received),
-                                                              NULL);
 }
 
 static QmiMessageLocSetOperationModeInput *
@@ -1240,16 +1235,6 @@ get_engine_lock_ready (QmiClientLoc *client,
         operation_shutdown (FALSE);
         return;
     }
-
-    /* Wait for response asynchronously */
-    ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
-                                             (GSourceFunc) get_engine_lock_timed_out,
-                                             NULL);
-
-    ctx->get_engine_lock_indication_id = g_signal_connect (ctx->client,
-                                                           "get-engine-lock",
-                                                           G_CALLBACK (get_engine_lock_received),
-                                                           NULL);
 }
 #endif /* HAVE_QMI_MESSAGE_LOC_GET_ENGINE_LOCK */
 
@@ -1300,16 +1285,6 @@ set_engine_lock_ready (QmiClientLoc *client,
         operation_shutdown (FALSE);
         return;
     }
-
-    /* Wait for response asynchronously */
-    ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
-                                             (GSourceFunc) set_engine_lock_timed_out,
-                                             NULL);
-
-    ctx->set_engine_lock_indication_id = g_signal_connect (ctx->client,
-                                                           "set-engine-lock",
-                                                           G_CALLBACK (set_engine_lock_received),
-                                                           NULL);
 }
 
 static QmiMessageLocSetEngineLockInput *
@@ -1401,6 +1376,266 @@ start_ready (QmiClientLoc *client,
 
 #endif /* HAVE_QMI_MESSAGE_LOC_START */
 
+#if defined HAVE_QMI_MESSAGE_LOC_INJECT_POSITION
+static void
+inject_position_received (QmiClientLoc                         *client,
+                          QmiIndicationLocInjectPositionOutput *output)
+{
+    QmiLocIndicationStatus  status;
+    g_autoptr(GError)       error = NULL;
+
+    if (!qmi_indication_loc_inject_position_output_get_indication_status (output, &status, &error)) {
+        g_printerr ("error: couldn't inject position %s\n", error->message);
+        operation_shutdown (FALSE);
+        return;
+    }
+
+    g_print ("Successfully inject position\n");
+    operation_shutdown (TRUE);
+}
+
+
+static gboolean
+inject_position_timed_out (void)
+{
+    ctx->timeout_id = 0;
+    g_printerr ("error: inject position operation failed: timeout\n");
+    operation_shutdown (FALSE);
+    return G_SOURCE_REMOVE;
+}
+
+
+static void
+inject_position_ready (QmiClientLoc *client,
+                       GAsyncResult *res)
+{
+    g_autoptr(QmiMessageLocInjectPositionOutput) output = NULL;
+    g_autoptr(GError)                            error = NULL;
+
+    output = qmi_client_loc_inject_position_finish (client, res, &error);
+    if (!output) {
+        g_printerr ("error: operation failed: %s\n", error->message);
+        operation_shutdown (FALSE);
+        return;
+    }
+
+    if (!qmi_message_loc_inject_position_output_get_result (output, &error)) {
+        g_printerr ("error: could not inject position: %s\n", error->message);
+        operation_shutdown (FALSE);
+        return;
+    }
+}
+
+static void
+inject_position_create (void)
+{
+    g_autoptr(QmiMessageLocInjectPositionInput) input = NULL;
+    GError                                     *error = NULL;
+    guint64                                     utc_ms = 0;
+
+    input = qmi_message_loc_inject_position_input_new ();
+    if (!input) {
+        operation_shutdown (FALSE);
+        return;
+    }
+
+    qmi_message_loc_inject_position_input_set_latitude (input, inject_position_latitude, &error);
+    qmi_message_loc_inject_position_input_set_longitude (input, inject_position_longitude, &error);
+    qmi_message_loc_inject_position_input_set_position_source (input, QMI_LOC_POSITION_SOURCE_OTHER, &error);
+
+    // it's not recommended to advertise accuracy better than 1000 meters to the modem
+    qmi_message_loc_inject_position_input_set_horizontal_uncertainty_circular (input, 1000, &error);
+    qmi_message_loc_inject_position_input_set_horizontal_confidence (input, 68, &error);
+
+    utc_ms = g_get_real_time () / 1000;
+    qmi_message_loc_inject_position_input_set_utc_timestamp (input, utc_ms, &error);
+
+    /* Wait for response asynchronously */
+    ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
+                                             (GSourceFunc) inject_position_timed_out,
+                                             NULL);
+
+    ctx->inject_position_indication_id = g_signal_connect (ctx->client,
+                                                           "inject-position",
+                                                           G_CALLBACK (inject_position_received),
+                                                           NULL);
+
+    qmi_client_loc_inject_position (ctx->client,
+                                    input,
+                                    10,
+                                    ctx->cancellable,
+                                    (GAsyncReadyCallback) inject_position_ready,
+                                    NULL);
+}
+#endif /* HAVE_QMI_MESSAGE_LOC_INJECT_POSITION */
+
+#if defined HAVE_QMI_MESSAGE_LOC_INJECT_UTC_TIME
+
+static gboolean
+inject_time_timed_out (void)
+{
+    ctx->timeout_id = 0;
+    g_printerr ("error: operation failed: timeout\n");
+    operation_shutdown (FALSE);
+    return G_SOURCE_REMOVE;
+}
+
+static void
+inject_time_received (QmiClientLoc                        *client,
+                      QmiIndicationLocInjectUtcTimeOutput *output)
+{
+    QmiLocIndicationStatus  status;
+    g_autoptr(GError)       error = NULL;
+
+    if (!qmi_indication_loc_inject_utc_time_output_get_indication_status (output, &status, &error)) {
+        g_printerr ("error: couldn't inject time %s\n", error->message);
+        operation_shutdown (FALSE);
+        return;
+    }
+
+    g_print ("Successfully injected time\n");
+    operation_shutdown (TRUE);
+}
+
+static void
+inject_time_ready (QmiClientLoc *client,
+                   GAsyncResult *res)
+{
+    g_autoptr(QmiMessageLocInjectUtcTimeOutput) output = NULL;
+    g_autoptr(GError)                           error = NULL;
+
+    output = qmi_client_loc_inject_utc_time_finish (client, res, &error);
+    if (!output) {
+        g_printerr ("error: operation failed: %s\n", error->message);
+        operation_shutdown (FALSE);
+        return;
+    }
+
+    if (!qmi_message_loc_inject_utc_time_output_get_result (output, &error)) {
+         g_printerr ("error: could not inject time: %s\n", error->message);
+         operation_shutdown (FALSE);
+         return;
+    }
+}
+
+static void
+inject_time_create (void)
+{
+    g_autoptr(QmiMessageLocInjectUtcTimeInput) input = NULL;
+    GError                                    *error = NULL;
+    guint64                                    utc_ms = 0;
+
+    input = qmi_message_loc_inject_utc_time_input_new ();
+    if (!input) {
+        operation_shutdown (FALSE);
+        return;
+    }
+
+    utc_ms = g_get_real_time () / 1000;
+    qmi_message_loc_inject_utc_time_input_set_utc_time (input, utc_ms, &error);
+    qmi_message_loc_inject_utc_time_input_set_time_uncertainty (input, 1000, &error);
+    qmi_message_loc_inject_utc_time_input_set_time_source (input, QMI_LOC_INJECTED_TIME_SOURCE_UNKNOWN, &error);
+
+    /* Wait for response asynchronously */
+    ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
+                                             (GSourceFunc) inject_time_timed_out,
+                                             NULL);
+
+    ctx->inject_time_indication_id = g_signal_connect (ctx->client,
+                                                       "inject-utc-time",
+                                                       G_CALLBACK (inject_time_received),
+                                                       NULL);
+
+    qmi_client_loc_inject_utc_time (ctx->client,
+                                    input,
+                                    10,
+                                    ctx->cancellable,
+                                    (GAsyncReadyCallback) inject_time_ready,
+                                    NULL);
+}
+#endif /* HAVE_QMI_MESSAGE_LOC_INJECT_UTC_TIME */
+
+#if defined HAVE_QMI_MESSAGE_LOC_GET_PREDICTED_ORBITS_DATA_SOURCE
+
+static gboolean
+get_predicted_orbits_data_source_timed_out (void)
+{
+    ctx->timeout_id = 0;
+    g_printerr ("error: operation failed: timeout\n");
+    operation_shutdown (FALSE);
+    return G_SOURCE_REMOVE;
+}
+
+static void
+get_predicted_orbits_data_source_received (QmiClientLoc                                       *client,
+                                           QmiIndicationLocGetPredictedOrbitsDataSourceOutput *output)
+{
+    QmiLocIndicationStatus  status;
+    g_autoptr(GError)       error = NULL;
+    GArray                 *servers = NULL;
+    guint32                 max_file_size = 0;
+    guint32                 max_part_size = 0;
+    guint                   i;
+
+    if (!qmi_indication_loc_get_predicted_orbits_data_source_output_get_indication_status (output, &status, &error)) {
+        g_printerr ("error: couldn't get predicted orbits data source: %s\n", error->message);
+        operation_shutdown (FALSE);
+        return;
+    }
+
+    g_print ("[%s] Predicted orbits data source received:\n",
+             qmi_device_get_path_display (ctx->device));
+
+    if (qmi_indication_loc_get_predicted_orbits_data_source_output_get_allowed_sizes (
+            output,
+            &max_file_size,
+            &max_part_size,
+            NULL)) {
+        g_print (
+             "\t   Allowed max file size: '%u'\n"
+             "\t   Allowed max part size: '%u'\n",
+             max_file_size,
+             max_part_size);
+    }
+
+    if (!qmi_indication_loc_get_predicted_orbits_data_source_output_get_server_list (
+            output,
+            &servers,
+            &error)) {
+        g_printerr ("error: couldn't get predicted orbits data source server list: %s\n", error->message);
+        operation_shutdown (FALSE);
+        return;
+    }
+
+    for (i = 0; i < servers->len; i++)
+        g_print ("\t   Server %u: '%s'\n", i + 1, g_array_index (servers, const gchar *, i));
+
+    g_print ("\nSuccessfully retrieved predicted orbits data source\n");
+    operation_shutdown (TRUE);
+}
+
+static void
+get_predicted_orbits_data_source_ready (QmiClientLoc *client,
+                                        GAsyncResult *res)
+{
+    g_autoptr(QmiMessageLocGetPredictedOrbitsDataSourceOutput) output = NULL;
+    g_autoptr(GError)                                          error = NULL;
+
+    output = qmi_client_loc_get_predicted_orbits_data_source_finish (client, res, &error);
+    if (!output) {
+        g_printerr ("error: operation failed: %s\n", error->message);
+        operation_shutdown (FALSE);
+        return;
+    }
+
+    if (!qmi_message_loc_get_predicted_orbits_data_source_output_get_result (output, &error)) {
+        g_printerr ("error: could not get predicted orbits data source: %s\n", error->message);
+        operation_shutdown (FALSE);
+        return;
+    }
+}
+#endif /* HAVE_QMI_MESSAGE_LOC_GET_PREDICTED_ORBITS_DATA_SOURCE */
+
 static gboolean
 noop_cb (gpointer unused)
 {
@@ -1462,6 +1697,17 @@ qmicli_loc_run (QmiDevice    *device,
 
         input = qmi_message_loc_delete_assistance_data_input_new ();
         qmi_message_loc_delete_assistance_data_input_set_delete_all (input, TRUE, NULL);
+
+        /* Wait for response asynchronously */
+        ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
+                                                 (GSourceFunc) delete_assistance_data_timed_out,
+                                                 NULL);
+
+        ctx->delete_assistance_data_indication_id = g_signal_connect (ctx->client,
+                                                                      "delete-assistance-data",
+                                                                      G_CALLBACK (delete_assistance_data_received),
+                                                                      NULL);
+
         qmi_client_loc_delete_assistance_data (ctx->client,
                                                input,
                                                10,
@@ -1475,6 +1721,15 @@ qmicli_loc_run (QmiDevice    *device,
 
 #if defined HAVE_QMI_MESSAGE_LOC_GET_NMEA_TYPES
     if (get_nmea_types_flag) {
+        /* Wait for response asynchronously */
+        ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
+                                                 (GSourceFunc) get_nmea_types_timed_out,
+                                                 NULL);
+
+        ctx->get_nmea_types_indication_id = g_signal_connect (ctx->client,
+                                                              "get-nmea-types",
+                                                              G_CALLBACK (get_nmea_types_received),
+                                                              NULL);
         qmi_client_loc_get_nmea_types (ctx->client,
                                        NULL,
                                        10,
@@ -1495,6 +1750,16 @@ qmicli_loc_run (QmiDevice    *device,
             operation_shutdown (FALSE);
             return;
         }
+
+        /* Wait for response asynchronously */
+        ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
+                                                 (GSourceFunc) set_nmea_types_timed_out,
+                                                 NULL);
+
+        ctx->set_nmea_types_indication_id = g_signal_connect (ctx->client,
+                                                              "set-nmea-types",
+                                                              G_CALLBACK (set_nmea_types_received),
+                                                              NULL);
         qmi_client_loc_set_nmea_types (ctx->client,
                                        input,
                                        10,
@@ -1507,6 +1772,15 @@ qmicli_loc_run (QmiDevice    *device,
 
 #if defined HAVE_QMI_MESSAGE_LOC_GET_OPERATION_MODE
     if (get_operation_mode_flag) {
+        /* Wait for response asynchronously */
+        ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
+                                                 (GSourceFunc) get_operation_mode_timed_out,
+                                                 NULL);
+
+        ctx->get_operation_mode_indication_id = g_signal_connect (ctx->client,
+                                                                  "get-operation-mode",
+                                                                  G_CALLBACK (get_operation_mode_received),
+                                                                  NULL);
         qmi_client_loc_get_operation_mode (ctx->client,
                                            NULL,
                                            10,
@@ -1527,6 +1801,16 @@ qmicli_loc_run (QmiDevice    *device,
             operation_shutdown (FALSE);
             return;
         }
+
+        /* Wait for response asynchronously */
+        ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
+                                                 (GSourceFunc) set_operation_mode_timed_out,
+                                                 NULL);
+
+        ctx->set_operation_mode_indication_id = g_signal_connect (ctx->client,
+                                                                  "set-operation-mode",
+                                                                  G_CALLBACK (set_operation_mode_received),
+                                                                  NULL);
         qmi_client_loc_set_operation_mode (ctx->client,
                                            input,
                                            10,
@@ -1539,6 +1823,15 @@ qmicli_loc_run (QmiDevice    *device,
 
 #if defined HAVE_QMI_MESSAGE_LOC_GET_ENGINE_LOCK
     if (get_engine_lock_flag) {
+        /* Wait for response asynchronously */
+        ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
+                                                 (GSourceFunc) get_engine_lock_timed_out,
+                                                 NULL);
+
+        ctx->get_engine_lock_indication_id = g_signal_connect (ctx->client,
+                                                               "get-engine-lock",
+                                                               G_CALLBACK (get_engine_lock_received),
+                                                               NULL);
         qmi_client_loc_get_engine_lock (ctx->client,
                                         NULL,
                                         10,
@@ -1559,6 +1852,16 @@ qmicli_loc_run (QmiDevice    *device,
             operation_shutdown (FALSE);
             return;
         }
+
+        /* Wait for response asynchronously */
+        ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
+                                                 (GSourceFunc) set_engine_lock_timed_out,
+                                                 NULL);
+
+        ctx->set_engine_lock_indication_id = g_signal_connect (ctx->client,
+                                                               "set-engine-lock",
+                                                               G_CALLBACK (set_engine_lock_received),
+                                                               NULL);
         qmi_client_loc_set_engine_lock (ctx->client,
                                         input,
                                         10,
@@ -1581,6 +1884,54 @@ qmicli_loc_run (QmiDevice    *device,
     }
 #endif
 
+#if defined HAVE_QMI_MESSAGE_LOC_INJECT_POSITION
+    if (!isnan (inject_position_latitude) ||
+        !isnan (inject_position_longitude)) {
+
+        if (isnan(inject_position_latitude) ||
+            isnan(inject_position_longitude) ||
+            (inject_position_latitude < -90) ||
+            (inject_position_latitude > 90)  ||
+            (inject_position_longitude < -180) ||
+            (inject_position_longitude > 180)) {
+            g_printerr ("error: correct values for both latitude and longitude has to be set.\n"
+                        "`--loc-inject-position-latitude [-90.0 .. 90.0] --loc-inject-position-longitude [-180.0 .. 180.0]'\n");
+            exit (EXIT_FAILURE);
+        }
+        g_debug ("Asynchronously inject position...");
+        inject_position_create ();
+        return;
+    }
+#endif
+#if defined HAVE_QMI_MESSAGE_LOC_INJECT_UTC_TIME
+    if (inject_time_flag) {
+        g_debug ("Asynchronously inject time...");
+        inject_time_create ();
+        return;
+    }
+#endif
+
+#if defined HAVE_QMI_MESSAGE_LOC_GET_PREDICTED_ORBITS_DATA_SOURCE
+    if (get_predicted_orbits_data_source_flag) {
+        /* Wait for response asynchronously */
+        ctx->timeout_id = g_timeout_add_seconds (timeout > 0 ? timeout : DEFAULT_LOC_TIMEOUT_SECS,
+                                                 (GSourceFunc) get_predicted_orbits_data_source_timed_out,
+                                                 NULL);
+
+        ctx->get_predicted_orbits_data_source_indication_id = g_signal_connect (ctx->client,
+                                                                                "get-predicted-orbits-data-source",
+                                                                                G_CALLBACK (get_predicted_orbits_data_source_received),
+                                                                                NULL);
+        qmi_client_loc_get_predicted_orbits_data_source (ctx->client,
+                                                         NULL,
+                                                         10,
+                                                         ctx->cancellable,
+                                                         (GAsyncReadyCallback) get_predicted_orbits_data_source_ready,
+                                                         ctx);
+        return;
+    }
+#endif
+
     /* Just client allocate/release? */
     if (noop_flag) {
         g_idle_add (noop_cb, NULL);
