@@ -161,4 +161,52 @@ void          qmicli_sar_run              (QmiDevice *device,
                                            GCancellable *cancellable);
 #endif
 
+#if defined HAVE_QMI_SERVICE_DPM
+GOptionGroup *qmicli_dpm_get_option_group (void);
+gboolean      qmicli_dpm_options_enabled  (void);
+void          qmicli_dpm_run              (QmiDevice *device,
+                                           QmiClientDpm *client,
+                                           GCancellable *cancellable);
+#endif
+
+#if defined HAVE_QMI_SERVICE_FOX
+GOptionGroup *qmicli_fox_get_option_group (void);
+gboolean      qmicli_fox_options_enabled  (void);
+void          qmicli_fox_run              (QmiDevice *device,
+                                           QmiClientFox *client,
+                                           GCancellable *cancellable);
+#endif
+
+#if defined HAVE_QMI_SERVICE_ATR
+GOptionGroup *qmicli_atr_get_option_group (void);
+gboolean      qmicli_atr_options_enabled  (void);
+void          qmicli_atr_run              (QmiDevice *device,
+                                           QmiClientAtr *client,
+                                           GCancellable *cancellable);
+#endif
+
+#if defined HAVE_QMI_SERVICE_IMSP
+GOptionGroup *qmicli_imsp_get_option_group (void);
+gboolean      qmicli_imsp_options_enabled  (void);
+void          qmicli_imsp_run              (QmiDevice *device,
+                                            QmiClientImsp *client,
+                                            GCancellable *cancellable);
+#endif
+
+#if defined HAVE_QMI_SERVICE_IMSA
+GOptionGroup *qmicli_imsa_get_option_group (void);
+gboolean      qmicli_imsa_options_enabled  (void);
+void          qmicli_imsa_run              (QmiDevice *device,
+                                            QmiClientImsa *client,
+                                            GCancellable *cancellable);
+#endif
+
+#if defined HAVE_QMI_SERVICE_IMS
+GOptionGroup *qmicli_ims_get_option_group (void);
+gboolean      qmicli_ims_options_enabled  (void);
+void          qmicli_ims_run              (QmiDevice *device,
+                                           QmiClientIms *client,
+                                           GCancellable *cancellable);
+#endif
+
 #endif /* __QMICLI_H__ */
